
"""bioticDETR package initialization.

See package README for introduction.

"""


import logging


logger = logging.getLogger(__name__)
"""Module logger."""


class bioticDETRError(Exception):
    """Base exception class for errors in this package."""




"""bioticDETR package main.

Launch point for command line use.
The root logger is configured with stream (info) and file (debug) handlers.

Usage:
    python -m bioticDETR

See package README for introduction.

"""


import logging

from absTools.execute import package_main_exec
from absTools.logs import LoggerCfg

import bioticDETR


logger = logging.getLogger(__name__)
"""Module logger."""


# Configure root logging
log_cfg = LoggerCfg('bioticDETRApp')


def main():
    logger.warning("Command line use is not implemented, "
                   "import bioticDETR package and use as a library")

    # raise SystemExit(1)


if __name__ == "__main__":
    package_main_exec(main)




"""bioticDETR build script for setuptools.

"""


import setuptools


with open("README.rst", "r") as readme_file:
    readme_description = readme_file.read()

setuptools.setup(
    name="bioticDETR",
    version="1.0.0.dev0",
    author="Calvin",
    author_email="calvin.isotope@gmail.com",
    description="Detection Transformers for Biotic Interactions",
    long_description=readme_description,
    long_description_content_type="text/x-rst",
    url="https://github.com/IsotopeC/bioticDETR",
    packages=setuptools.find_packages(exclude=['docs', 'tests', 'logs', 'examples']),
    classifiers=["Programming Language :: Python :: 3",
                 "Operating System :: OS Independent"],
    keywords='DETR AI Biotic Interactions',
    install_requires=['numpy', 'pandas'],
    python_requires='>3.9'
)
